declare const _default: {
    "baseUrl": string;
    "servicePath": string;
    "kind": string;
    "description": string;
    "basePath": string;
    "revision": string;
    "documentationLink": string;
    "id": string;
    "discoveryVersion": string;
    "version_module": boolean;
    "schemas": {
        "Status": {
            "description": string;
            "type": string;
            "properties": {
                "code": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "message": {
                    "description": string;
                    "type": string;
                };
                "details": {
                    "description": string;
                    "type": string;
                    "items": {
                        "type": string;
                        "additionalProperties": {
                            "description": string;
                            "type": string;
                        };
                    };
                };
            };
            "id": string;
        };
        "Features": {
            "description": string;
            "type": string;
            "properties": {
                "extractSyntax": {
                    "description": string;
                    "type": string;
                };
                "extractDocumentSentiment": {
                    "description": string;
                    "type": string;
                };
                "extractEntitySentiment": {
                    "description": string;
                    "type": string;
                };
                "extractEntities": {
                    "description": string;
                    "type": string;
                };
                "classifyText": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "Document": {
            "properties": {
                "language": {
                    "description": string;
                    "type": string;
                };
                "type": {
                    "enum": string[];
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                };
                "content": {
                    "description": string;
                    "type": string;
                };
                "gcsContentUri": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "AnalyzeEntitiesRequest": {
            "description": string;
            "type": string;
            "properties": {
                "document": {
                    "$ref": string;
                    "description": string;
                };
                "encodingType": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "ClassifyTextRequest": {
            "description": string;
            "type": string;
            "properties": {
                "document": {
                    "description": string;
                    "$ref": string;
                };
            };
            "id": string;
        };
        "AnalyzeEntitySentimentResponse": {
            "description": string;
            "type": string;
            "properties": {
                "language": {
                    "description": string;
                    "type": string;
                };
                "entities": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "id": string;
        };
        "AnalyzeSentimentResponse": {
            "description": string;
            "type": string;
            "properties": {
                "sentences": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "documentSentiment": {
                    "description": string;
                    "$ref": string;
                };
                "language": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "AnalyzeSyntaxResponse": {
            "description": string;
            "type": string;
            "properties": {
                "sentences": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "tokens": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "language": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "AnnotateTextResponse": {
            "properties": {
                "entities": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "sentences": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "tokens": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "categories": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "documentSentiment": {
                    "description": string;
                    "$ref": string;
                };
                "language": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "DependencyEdge": {
            "properties": {
                "label": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "headTokenIndex": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "TextSpan": {
            "description": string;
            "type": string;
            "properties": {
                "beginOffset": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "content": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "Token": {
            "description": string;
            "type": string;
            "properties": {
                "partOfSpeech": {
                    "description": string;
                    "$ref": string;
                };
                "text": {
                    "description": string;
                    "$ref": string;
                };
                "dependencyEdge": {
                    "$ref": string;
                    "description": string;
                };
                "lemma": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "EntityMention": {
            "description": string;
            "type": string;
            "properties": {
                "text": {
                    "description": string;
                    "$ref": string;
                };
                "type": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "sentiment": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "ClassifyTextResponse": {
            "description": string;
            "type": string;
            "properties": {
                "categories": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "id": string;
        };
        "Sentence": {
            "description": string;
            "type": string;
            "properties": {
                "text": {
                    "$ref": string;
                    "description": string;
                };
                "sentiment": {
                    "description": string;
                    "$ref": string;
                };
            };
            "id": string;
        };
        "Sentiment": {
            "description": string;
            "type": string;
            "properties": {
                "score": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "magnitude": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "AnalyzeEntitySentimentRequest": {
            "properties": {
                "document": {
                    "$ref": string;
                    "description": string;
                };
                "encodingType": {
                    "enum": string[];
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                };
            };
            "id": string;
            "description": string;
            "type": string;
        };
        "PartOfSpeech": {
            "description": string;
            "type": string;
            "properties": {
                "proper": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "case": {
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                };
                "tense": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "reciprocity": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "form": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "number": {
                    "enum": string[];
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                };
                "voice": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "aspect": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "mood": {
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                };
                "tag": {
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                };
                "gender": {
                    "enum": string[];
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                };
                "person": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "ClassificationCategory": {
            "description": string;
            "type": string;
            "properties": {
                "confidence": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "name": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "AnalyzeSyntaxRequest": {
            "description": string;
            "type": string;
            "properties": {
                "encodingType": {
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                };
                "document": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "AnalyzeEntitiesResponse": {
            "description": string;
            "type": string;
            "properties": {
                "entities": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "language": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "Entity": {
            "description": string;
            "type": string;
            "properties": {
                "mentions": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "name": {
                    "description": string;
                    "type": string;
                };
                "type": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "metadata": {
                    "description": string;
                    "type": string;
                    "additionalProperties": {
                        "type": string;
                    };
                };
                "salience": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "sentiment": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "AnnotateTextRequest": {
            "description": string;
            "type": string;
            "properties": {
                "encodingType": {
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                    "type": string;
                };
                "document": {
                    "description": string;
                    "$ref": string;
                };
                "features": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "AnalyzeSentimentRequest": {
            "description": string;
            "type": string;
            "properties": {
                "encodingType": {
                    "description": string;
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                };
                "document": {
                    "description": string;
                    "$ref": string;
                };
            };
            "id": string;
        };
    };
    "protocol": string;
    "icons": {
        "x32": string;
        "x16": string;
    };
    "canonicalName": string;
    "auth": {
        "oauth2": {
            "scopes": {
                "https://www.googleapis.com/auth/cloud-platform": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/cloud-language": {
                    "description": string;
                };
            };
        };
    };
    "rootUrl": string;
    "ownerDomain": string;
    "name": string;
    "batchPath": string;
    "title": string;
    "ownerName": string;
    "resources": {
        "documents": {
            "methods": {
                "classifyText": {
                    "path": string;
                    "id": string;
                    "request": {
                        "$ref": string;
                    };
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {};
                    "flatPath": string;
                };
                "analyzeSentiment": {
                    "request": {
                        "$ref": string;
                    };
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {};
                    "flatPath": string;
                    "path": string;
                    "id": string;
                };
                "analyzeEntitySentiment": {
                    "request": {
                        "$ref": string;
                    };
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {};
                    "flatPath": string;
                    "path": string;
                    "id": string;
                };
                "analyzeEntities": {
                    "flatPath": string;
                    "path": string;
                    "id": string;
                    "request": {
                        "$ref": string;
                    };
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {};
                };
                "analyzeSyntax": {
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "parameters": {};
                    "scopes": string[];
                    "flatPath": string;
                    "path": string;
                    "id": string;
                    "description": string;
                    "request": {
                        "$ref": string;
                    };
                };
                "annotateText": {
                    "description": string;
                    "request": {
                        "$ref": string;
                    };
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": never[];
                    "httpMethod": string;
                    "parameters": {};
                    "scopes": string[];
                    "flatPath": string;
                    "path": string;
                    "id": string;
                };
            };
        };
    };
    "parameters": {
        "callback": {
            "description": string;
            "type": string;
            "location": string;
        };
        "oauth_token": {
            "description": string;
            "type": string;
            "location": string;
        };
        "$.xgafv": {
            "description": string;
            "type": string;
            "enumDescriptions": string[];
            "location": string;
            "enum": string[];
        };
        "alt": {
            "type": string;
            "enumDescriptions": string[];
            "location": string;
            "description": string;
            "default": string;
            "enum": string[];
        };
        "access_token": {
            "description": string;
            "type": string;
            "location": string;
        };
        "key": {
            "description": string;
            "type": string;
            "location": string;
        };
        "upload_protocol": {
            "description": string;
            "type": string;
            "location": string;
        };
        "prettyPrint": {
            "description": string;
            "type": string;
            "default": string;
            "location": string;
        };
        "quotaUser": {
            "description": string;
            "type": string;
            "location": string;
        };
        "fields": {
            "location": string;
            "description": string;
            "type": string;
        };
        "uploadType": {
            "location": string;
            "description": string;
            "type": string;
        };
    };
    "version": string;
};
export default _default;
//# sourceMappingURL=language-v1.d.ts.map